==> brevo-1.0.1.tar.gz: brevo/src/BrevoHandler.php <==
<?php

namespace Drupal\brevo;

use Brevo\Client\ApiException;
use Brevo\Client\Model\SendSmtpEmail;
use Drupal\Component\Utility\EmailValidatorInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Psr\Log\LoggerInterface;

/**
 * Mail handler to send out an email message array to the Brevo API.
 */
class BrevoHandler implements BrevoHandlerInterface {

  /**
   * Brevo factory.
   *
   * @var \Drupal\brevo\BrevoFactory
   */
  protected $brevoFactory;

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $brevoConfig;

  /**
   * Logger service.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Brevo Transactional emails API client.
   *
   * @var \Brevo\Client\Api\TransactionalEmailsApi
   */
  protected $brevo;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The email validator.
   *
   * @var \Drupal\Component\Utility\EmailValidatorInterface
   */
  protected $emailValidator;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs a new \Drupal\brevo\BrevoHandler object.
   *
   * @param \Drupal\brevo\BrevoFactory $brevo_factory
   *   Brevo factory service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   * @param \Drupal\Component\Utility\EmailValidatorInterface $email_validator
   *   The email validator.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   */
  public function __construct(BrevoFactory $brevo_factory, ConfigFactoryInterface $config_factory, LoggerInterface $logger, MessengerInterface $messenger, EmailValidatorInterface $email_validator, ModuleHandlerInterface $module_handler) {
    $this->brevoConfig = $config_factory->get(BrevoHandlerInterface::CONFIG_NAME);
    $this->logger = $logger;
    $this->brevoFactory = $brevo_factory;
    $this->brevo =  $this->brevoFactory->createTransactionalEmailsApiClient();
    $this->messenger = $messenger;
    $this->emailValidator = $email_validator;
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public function sendMail(array $brevoMessage) {
    try {
      if (!$this->validateBrevoApiSettings()) {
        $this->logger->error('Failed to send message from %from to %to. Please check the Brevo settings.',
          [
            '%from' => $brevoMessage['from'],
            '%to' => $this->getRecipients($brevoMessage),
          ]
        );
        return FALSE;
      }

      // Prepare the Brevo SDK method parameters.
      // @see https://developers.brevo.com/reference/sendtransacemail
      $params = new SendSmtpEmail($brevoMessage);
      $response = $this->brevo->sendTransacEmail($params);

      // Debug mode: log all messages.
      if ($this->brevoConfig->get('debug_mode')) {
        $this->logger->notice('Successfully sent message from %from to %to. %id.',
          [
            '%from' => $brevoMessage['sender']['email'],
            '%to' => $this->getRecipients($brevoMessage),
            '%id' => $response->getMessageId(),
          ]
        );
      }
      return $response;
    }
    catch (ApiException $e) {
      $this->logger->error('Exception occurred while trying to send test email from %from to %to. Error code @code: @message',
        [
          '%from' => $brevoMessage['sender']['email'],
          '%to' => $this->getRecipients($brevoMessage),
          '@code' => $e->getCode(),
          '@message' => $e->getMessage(),
        ]
      );
      return FALSE;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function moduleStatus($showMessage = FALSE) {
    return $this->validateBrevoLibrary($showMessage)
      && $this->validateDrupalMailerLibrary($showMessage)
      && $this->validateBrevoApiSettings($showMessage);
  }

  /**
   * {@inheritdoc}
   */
  public function validateBrevoApiKey($key) {
    if (!$this->validateBrevoLibrary()) {
      return FALSE;
    }

    try {
      $brevo = $this->brevoFactory->createAccountApiClient($key);
      $brevo->getAccount();
    }
    catch (ApiException $e) {
      return FALSE;
    }

    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function validateBrevoApiSettings($showMessage = FALSE) {
    $apiKey = $this->brevoConfig->get('api_key');
    if (empty($apiKey)) {
      if ($showMessage) {
        $this->messenger->addMessage("Please check your API settings. API key shouldn't be empty.", 'warning');
      }
      return FALSE;
    }

    if (!$this->validateBrevoApiKey($apiKey)) {
      if ($showMessage) {
        $this->messenger->addMessage("Couldn't connect to the Brevo API. Please check your API settings.", 'warning');
      }
      return FALSE;
    }

    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function validateDrupalMailerLibrary($showMessage = FALSE) {
    $libraryStatus = TRUE;
    $modules = $this->moduleHandler->getModuleList();
    if (empty($modules['mailsystem']) && empty($modules['symfony_mailer'])) {
      $libraryStatus = FALSE;
      if ($showMessage) {
        $this->messenger->addMessage('You must install one of the following drupal modules : "Mail System" or "Symfony Mailer".', 'warning');
      }
    }

    // Check for the Symfony Mailer dependencies.
    if (!empty($modules['symfony_mailer'])) {
      if (!class_exists('\Symfony\Component\Mailer\Bridge\Brevo\Transport\BrevoApiTransport')) {
        $libraryStatus = FALSE;
        if ($showMessage) {
          $this->messenger->addMessage('You must install the "symfony/brevo-mailer" dependency (with composer).', 'warning');
        }
      }

      if (!class_exists('\Symfony\Component\HttpClient\HttpClient')) {
        $libraryStatus = FALSE;
        if ($showMessage) {
          $this->messenger->addMessage('You must install the "symfony/http-client" dependency (with composer).', 'warning');
        }
      }
    }

    return $libraryStatus;
  }

  /**
   * {@inheritdoc}
   */
  public function validateBrevoLibrary($showMessage = FALSE) {
    $libraryStatus = class_exists('\Brevo\Client\Api\TransactionalEmailsApi');
    if ($showMessage === FALSE) {
      return $libraryStatus;
    }

    if ($libraryStatus === FALSE) {
      $this->messenger->addMessage('The Brevo library has not been installed correctly.', 'warning');
    }
    return $libraryStatus;
  }

  /**
   * Returns a list of recipients for error/debug log message.
   *
   * @param array $brevoMessage
   *   A message array, as described in
   *   https://developers.brevo.com/docs/send-a-transactional-email.
   *
   * @return string
   *   Recipients list in the following format:
   *   user@test.com, user1@test.com; cc: user2@test.com; bcc: user3@test.com.
   */
  protected function getRecipients(array $brevoMessage) {
    $recipients = '';

    // Add all recipients (including 'cc' and 'bcc').
    foreach (['to', 'cc', 'bcc'] as $parameter) {
      if (!empty($brevoMessage[$parameter])) {
        foreach ($brevoMessage[$parameter] as $recipient) {
          $recipients .= "; {$parameter}: {$recipient['email']}";
        }
      }
    }

    return $recipients;
  }

}

==> brevo-1.0.2.tar.gz: brevo/src/BrevoHandler.php <==
<?php

namespace Drupal\brevo;

use Brevo\Client\ApiException;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Psr\Log\LoggerInterface;

/**
 * Mail handler to send out an email message array to the Brevo API.
 */
class BrevoHandler implements BrevoHandlerInterface {

  /**
   * Brevo factory.
   *
   * @var \Drupal\brevo\BrevoFactory
   */
  protected $brevoFactory;

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $brevoConfig;

  /**
   * Logger service.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Brevo Transactional emails API client.
   *
   * @var \Brevo\Client\Api\TransactionalEmailsApi
   */
  protected $brevo;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a new \Drupal\brevo\BrevoHandler object.
   *
   * @param \Drupal\brevo\BrevoFactory $brevo_factory
   *   Brevo factory service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   */
  public function __construct(BrevoFactory $brevo_factory, ConfigFactoryInterface $config_factory, LoggerInterface $logger, MessengerInterface $messenger) {
    $this->brevoConfig = $config_factory->get(BrevoHandlerInterface::CONFIG_NAME);
    $this->logger = $logger;
    $this->brevoFactory = $brevo_factory;
    $this->brevo =  $this->brevoFactory->createTransactionalEmailsApiClient();
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public function moduleStatus($showMessage = FALSE) {
    return $this->validateBrevoLibrary($showMessage)
      && $this->validateBrevoApiSettings($showMessage);
  }

  /**
   * {@inheritdoc}
   */
  public function validateBrevoApiKey($key) {
    if (!$this->validateBrevoLibrary()) {
      return FALSE;
    }

    try {
      $brevo = $this->brevoFactory->createAccountApiClient($key);
      $brevo->getAccount();
    }
    catch (ApiException $e) {
      return FALSE;
    }

    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function validateBrevoApiSettings($showMessage = FALSE) {
    $apiKey = $this->brevoConfig->get('api_key');
    if (empty($apiKey)) {
      if ($showMessage) {
        $this->messenger->addMessage("Please check your API settings. API key shouldn't be empty.", 'warning');
      }
      return FALSE;
    }

    if (!$this->validateBrevoApiKey($apiKey)) {
      if ($showMessage) {
        $this->messenger->addMessage("Couldn't connect to the Brevo API. Please check your API settings.", 'warning');
      }
      return FALSE;
    }

    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function validateBrevoLibrary($showMessage = FALSE) {
    $libraryStatus = class_exists('\Brevo\Client\Api\TransactionalEmailsApi');
    if ($showMessage === FALSE) {
      return $libraryStatus;
    }

    if ($libraryStatus === FALSE) {
      $this->messenger->addMessage('The Brevo library has not been installed correctly.', 'warning');
    }
    return $libraryStatus;
  }

}
